/** \file brd_init.c
 * brd_init.c
 *
 * This file functions necessary to initialize the board to run VPP demo.
 *
 * Copyright (c) 2008, Zarlink Semiconductor Inc.
 * All rights reserved
 *
 * This software is the property of Zarlink Semiconductor , Inc. Please refer to the
 * Non Disclosure Agreement (NDA) that you have signed for more information
 * on legal obligations in using, modifying or distributing this file.
 */

#include <stdlib.h>
#include <stdio.h>

#include "brd_init.h"

#ifdef LEGERITY_UVB_DEMO_BOARD
/* The following include is necessary only in the Zarlink Semiconductor UVB build
 * environment */
#include "../../../lib/uvb_xs/uvb_xs.h"
#endif /* LEGERITY_UVB_DEMO_BOARD */

#define term_printf printf
#define CHANGE_ALL_BITS 0xffff

/*
 * InitializeBoard()
 * This function is used to perform Board initialization that is necessary
 * to run the VPP demo.
 *
 * Preconditions:
 * None
 *
 * Postconditions:
 * Resets the device, places the DIN connector in HBI, 8bit seperate rd/wr mode,
 * then releases the reset to the part.
 */
void
InitializeBoard(
    void)
{

#ifdef LEGERITY_UVB_DEMO_BOARD

    /* Implement necessary initialization that are needed to be able to talk to
     * VCP or VPP device on the board. The following code illustrates necessary
     * steps required on Zarlink Semiconductor UVB development board. */

    if((chipSelect & 0x0010) == 0) {
        term_printf("Configuring DIN connector in HBI interface mode...\n");

        term_printf("Holding the DIN connector in reset\n");
        CPLD_Write(CC_REG, CHANGE_ALL_BITS, 0x00037);

        term_printf("Setting HBI clock\n");
        CPLD_Write(CLKFC_REG, CHANGE_ALL_BITS, 0x0660);

        term_printf("setting HBI config pins\n");
        CPLD_Write(MISC_REG, CHANGE_ALL_BITS, 0x0090);

        term_printf("Releasing the DIN connector reset\n");
        CPLD_Write(CC_REG, CHANGE_ALL_BITS, 0x0077);

    } else if ((chipSelect & 0x0010) == 0x0010) {
        term_printf("Configuring small connector in HBI interface mode...\n");

        term_printf("Holding the small connector in reset\n");
        CPLD_Write(CC_REG, CHANGE_ALL_BITS, 0x0047);

        term_printf("Setting HBI clock\n");
        CPLD_Write(CLKFC_REG, CHANGE_ALL_BITS, 0x0660);

        term_printf("setting HBI config pins\n");
        CPLD_Write(MISC_REG, CHANGE_ALL_BITS, 0x0010);

        term_printf("Releasing the small connector reset\n");
        CPLD_Write(CC_REG, CHANGE_ALL_BITS, 0x0067);

    } else {
        term_printf("ERROR: Do not know how to initialize the board\n");
        exit(0);
    }

    term_printf("Board Setup complete.\n");

#endif /* LEGERITY_UVB_DEMO_BOARD */

} /* InitializeBoard() */
