/*
 * profiles8.c --
 *
 * This file contains profile data in byte format
 *
 * Copyright (c) 2004 Zarlink Semiconductor Inc.
 * All rights reserved.
 * Zarlink Semiconductor confidential and proprietary information.
 *
 * Project Info --
 *   File:  L:\uvb\sdk\apps\qs_le71hr0803_dat\LE71HE0803-MiniPBX.vpw
 *   Type:  VP880-CP5621 VoicePort MiniPBX Project (Line Module LE71HE0803)
 *   Date:  Wednesday, September 15, 2004 12:29:09
 */

#include "profiles8_880.h"
#include "app_des.h"    /* Provides Description of hardware and VCP-firmware
                         * product type*/
#ifndef VP_CC_VCP_790_SERIES

/************** Device Parameters **************/
const VpProfileDataType DEV_PROFILE[] =
{
 0x00, 0xFF, 0x00, 0x0E, /* Profile Index and Length */
 0x01, 0x00, /* Version and MPI Command */
 0x20, 0x00, /* PCLK Frequency */
 0x8A, 0x00, /* Device Config 1 and MCLK Correction */
 0x40, 0x05, /* Clock Slot and Max Events */
 0x05, 0x00, /* Device Tickrate */
 0xE4, 0x00, 0x11, 0x05  /* Switching Regulator Parameters */
};

/************** AC Filter Coefficients **************/

/* AC 600 FXO Coefficients */
const VpProfileDataType AC_600R_FXO[] =
{
  /* AC Profile */
 0x00, 0x00, 0x00, 0x4C, 0x00, 0x49, 0x8A, 0x2E, 0x01, 0x01, 0x11, 0x01,
 0x90, 0x01, 0x90, 0x01, 0x90, 0x01, 0x90, 0x01, 0x90, 0x9A, 0x01, 0x90,
 0x01, 0x01, 0x90, 0x50, 0x50, 0x80, 0x98, 0x00, 0x82, 0xC2, 0x21, 0x86,
 0x4A, 0xCC, 0xA9, 0xC4, 0x92, 0x2B, 0x98, 0xE2, 0x97, 0x29, 0x7A, 0x87,
 0xA8, 0x70, 0x88, 0x01, 0x11, 0x01, 0x90, 0x01, 0x90, 0x01, 0x90, 0x01,
 0x90, 0x01, 0x90, 0x96, 0x2E, 0x01, 0x98, 0x01, 0x90, 0x01, 0x90, 0x01,
 0x90, 0x01, 0x90, 0x01, 0x90, 0xCA, 0x00, 0x00
};

/* AC 600 FXS Coefficients */
const VpProfileDataType AC_600R_FXS[] =
{
  /* AC Profile */
 0x00, 0x00, 0x01, 0x4C, 0x00, 0x49, 0xCA, 0xFA, 0x98, 0xCA, 0xB9, 0xA2,
 0x4C, 0x2B, 0xA2, 0xA3, 0xA2, 0xAE, 0x2B, 0x9A, 0x23, 0xCA, 0x26, 0x9F,
 0x01, 0x8A, 0x1D, 0x01, 0x01, 0x11, 0x01, 0x90, 0x01, 0x90, 0x01, 0x90,
 0x01, 0x90, 0x01, 0x90, 0x88, 0xD8, 0x70, 0x7A, 0x87, 0x23, 0x3F, 0x4A,
 0x97, 0x5A, 0xA7, 0x5A, 0xAF, 0x82, 0x22, 0xE0, 0x80, 0x32, 0x10, 0x50,
 0x10, 0x86, 0xA2, 0x63, 0x23, 0xBB, 0x2A, 0xA4, 0x29, 0x7D, 0x87, 0x2A,
 0xFA, 0x8F, 0x29, 0xF0, 0x96, 0x2E, 0x01, 0x00
};

/************** DC Feed Parameters **************/

/* 25 mA current feed */
const VpProfileDataType DC_25MA_CC[] =
{
 /* DC Profile */
 0x00, 0x01, 0x01, 0x0A, 0x00, 0x08, 0xC2, 0x1B, 0x84, 0xB4, 0x05, 0xC6,
 0x0B, 0x08
};

/* 40mA Resistive feed */
const VpProfileDataType DC_40MA_RF[] =
{
 /* DC Profile */
 0x00, 0x01, 0x02, 0x0A, 0x00, 0x08, 0xC2, 0x1B, 0x84, 0xC6, 0x07, 0xC6,
 0x08, 0x16
};

/************** Ring Signal Parameters **************/

/* 20Hz, Sinewave ringing, 66Vpk */
const VpProfileDataType RING_20HZ_SINE[] =
{
 /* Sine, 20 Hz, 1.41 CF, 66.00 Vpk, 0.00 Bias */
  /* Ringing Profile */
 0x00, 0x04, 0x01, 0x10, 0x00, 0x0E, 0xD2, 0x00, 0x00, 0x00, 0x00, 0x36,
 0x36, 0xB7, 0x00, 0x00, 0x00, 0x00, 0x68, 0x04
};

/* 25Hz, Sinewave ringing, 80Vpk */
const VpProfileDataType RING_25HZ_SINE[] =
{
 /* Sine, 25 Hz, 1.41 CF, 80.00 Vpk, 0.00 Bias */
  /* Ringing Profile */
 0x00, 0x04, 0x01, 0x10, 0x00, 0x0E, 0xD2, 0x00, 0x00, 0x00, 0x00, 0x44,
 0x42, 0x52, 0x00, 0x00, 0x00, 0x00, 0x68, 0x04
};

/* 40Hz trapezoidal ringing, Vpk = 80V, CF = 1.25 */
const VpProfileDataType RING_40HZ_TRAP[] =
{
 /* Trap, 40 Hz, 1.25 CF, 80.00 Vpk, 0.00 Bias */
  /* Ringing Profile */
 0x00, 0x04, 0x01, 0x10, 0x00, 0x0E, 0xD2, 0x01, 0x00, 0x00, 0x00, 0x6D,
 0x42, 0x52, 0x00, 0x00, 0x00, 0x00, 0x68, 0x04
};

/************** Call Progress Tones **************/

/* US Dial Tone */
const VpProfileDataType TONE_DIAL[] =
{
 /* 350 Hz, -13.00 dBm0, 440 Hz, -13.00 dBm0, 350 Hz, -13.00 dBm0, 440 Hz, -13.00 dBm0 */
 /* Tone Profile */
 0x00, 0x02, 0x01, 0x14, 0x00, 0x00, 0x00, 0x00, 0x03, 0xBB, 0x13, 0xF6,
 0x04, 0xB1, 0x13, 0xF6, 0x03, 0xBB, 0x13, 0xF6, 0x04, 0xB1, 0x13, 0xF6
};

/* Special Information Tone (Called Number Not Connected) */
const VpProfileDataType TONE_SIT[] =
{
 /* 950 Hz, -8.00 dBm0, 1400 Hz, -8.00 dBm0, 1800 Hz, -8.00 dBm0, 0 Hz, 0.00 dBm0 */
 /* Tone Profile */
 0x00, 0x02, 0x01, 0x14, 0x00, 0x00, 0x00, 0x00, 0x0A, 0x22, 0x23, 0x7F,
 0x0E, 0xEF, 0x23, 0x7F, 0x13, 0x33, 0x23, 0x7F, 0x00, 0x00, 0x00, 0x00
};

/* Busy Signal */
const VpProfileDataType TONE_BUSY[] =
{
 /* 480 Hz, -16.00 dBm0, 620 Hz, -16.00 dBm0, 480 Hz, -16.00 dBm0, 620 Hz, -16.00 dBm0 */
 /* Tone Profile */
 0x00, 0x02, 0x01, 0x14, 0x00, 0x00, 0x00, 0x00, 0x05, 0x1E, 0x0E, 0x21,
 0x06, 0x9D, 0x0E, 0x21, 0x05, 0x1E, 0x0E, 0x21, 0x06, 0x9D, 0x0E, 0x21
};

/* Standard Ringback */
const VpProfileDataType TONE_RINGBACK[] =
{
 /* 440 Hz, -13.00 dBm0, 480 Hz, -13.00 dBm0, 440 Hz, -13.00 dBm0, 480 Hz, -13.00 dBm0 */
 /* Tone Profile */
 0x00, 0x02, 0x01, 0x14, 0x00, 0x00, 0x00, 0x00, 0x04, 0xB1, 0x13, 0xF6,
 0x05, 0x1E, 0x13, 0xF6, 0x04, 0xB1, 0x13, 0xF6, 0x05, 0x1E, 0x13, 0xF6
};

/* Call Waiting Beep */
const VpProfileDataType TONE_CALLWAIT[] =
{
 /* 440 Hz, -13.00 dBm0, 0 Hz, 6.02 dBm0, 440 Hz, 0.00 dBm0, 0 Hz, -13.00 dBm0 */
 /* Tone Profile */
 0x00, 0x02, 0x01, 0x14, 0x00, 0x00, 0x00, 0x00, 0x04, 0xB1, 0x13, 0xF6,
 0x00, 0x00, 0x00, 0x00, 0x04, 0xB1, 0x59, 0x2A, 0x00, 0x00, 0x00, 0x00
};

/* US Reorder tone */
const VpProfileDataType TONE_REORDER[] =
{
 /* 480 Hz, -16.00 dBm0, 620 Hz, -16.00 dBm0, 440 Hz, 0.00 dBm0, 0 Hz, -13.00 dBm0 */
 /* Tone Profile */
 0x00, 0x02, 0x01, 0x14, 0x00, 0x00, 0x00, 0x00, 0x05, 0x1E, 0x0E, 0x21,
 0x06, 0x9D, 0x0E, 0x21, 0x04, 0xB1, 0x59, 0x2A, 0x00, 0x00, 0x00, 0x00
};

/* A 1kHz tone at -10dBm0 */
const VpProfileDataType TONE_ONEKHZ_L[] =
{
 /* 1000 Hz, -10.00 dBm0, 0 Hz, -13.00 dBm0, 440 Hz, 0.00 dBm0, 0 Hz, -13.00 dBm0 */
 /* Tone Profile */
 0x00, 0x02, 0x01, 0x14, 0x00, 0x00, 0x00, 0x00, 0x0A, 0xAA, 0x1C, 0x32,
 0x00, 0x00, 0x00, 0x00, 0x04, 0xB1, 0x59, 0x2A, 0x00, 0x00, 0x00, 0x00
};

/* A 1kHz tone at 0dBm0 */
const VpProfileDataType TONE_ONEKHZ_H[] =
{
 /* 1000 Hz, 0.00 dBm0, 0 Hz, -13.00 dBm0, 440 Hz, 0.00 dBm0, 0 Hz, -13.00 dBm0 */
 /* Tone Profile */
 0x00, 0x02, 0x01, 0x14, 0x00, 0x00, 0x00, 0x00, 0x0A, 0xAA, 0x59, 0x2A,
 0x00, 0x00, 0x00, 0x00, 0x04, 0xB1, 0x59, 0x2A, 0x00, 0x00, 0x00, 0x00
};

/* Caller ID Alert Tone for UK Cadence */
const VpProfileDataType TONE_CLI[] =
{
 /* 2130 Hz, -13.00 dBm0, 2750 Hz, -13.00 dBm0, 440 Hz, 0.00 dBm0, 0 Hz, -13.00 dBm0 */
 /* Tone Profile */
 0x00, 0x02, 0x01, 0x14, 0x00, 0x00, 0x00, 0x00, 0x16, 0xB8, 0x13, 0xF6,
 0x1D, 0x55, 0x13, 0xF6, 0x04, 0xB1, 0x59, 0x2A, 0x00, 0x00, 0x00, 0x00
};

/* Receiver Off-Hook */
const VpProfileDataType TONE_ROH[] =
{
 /* 1400 Hz, 0.00 dBm0, 2060 Hz, 0.00 dBm0, 2450 Hz, 0.00 dBm0, 2600 Hz, 0.00 dBm0 */
 /* Tone Profile */
 0x00, 0x02, 0x01, 0x14, 0x00, 0x00, 0x00, 0x00, 0x0E, 0xEF, 0x59, 0x2A,
 0x15, 0xF9, 0x59, 0x2A, 0x1A, 0x22, 0x59, 0x2A, 0x1B, 0xBB, 0x59, 0x2A
};

/************** Cadence Definitions **************/

/* Standard dial tone cadence */
const VpProfileDataType TONE_CAD_DIAL0[] =
{
  /* Cadence Profile */
 0x00, 0x03, 0x01, 0x08, 0x00, 0x00, 0x00, 0x04, 0x00, 0x8F, 0x20, 0x00
};

/* Stutter dial tone cadence */
const VpProfileDataType TONE_CAD_DIAL1[] =
{
  /* Cadence Profile */
 0x00, 0x03, 0x01, 0x12, 0x00, 0x00, 0x00, 0x0E, 0x00, 0x8F, 0x20, 0x14,
 0x00, 0x80, 0x20, 0x14, 0x40, 0x03, 0x00, 0x8F, 0x40, 0x00
};

/* Busy signal cadence (0.5 sec on 0.5 sec off) */
const VpProfileDataType TONE_CAD_BUSY0[] =
{
  /* Cadence Profile */
 0x00, 0x03, 0x01, 0x0E, 0x00, 0x00, 0x00, 0x0A, 0x00, 0x8F, 0x20, 0x64,
 0x00, 0x80, 0x20, 0x64, 0x40, 0x00
};

/* Tone Reorder cadence (0.25 sec on 0.25 sec off) */
const VpProfileDataType TONE_CAD_REORDER[] =
{
  /* Cadence Profile */
 0x00, 0x03, 0x01, 0x0E, 0x00, 0x00, 0x00, 0x0A, 0x00, 0x8F, 0x20, 0x32,
 0x00, 0x80, 0x20, 0x32, 0x40, 0x00
};

/* Standard Ringing Cadence (2 sec on 4 sec off) */
const VpProfileDataType RING_CAD_STD[] =
{
  /* Cadence Profile */
 0x00, 0x08, 0x01, 0x16, 0x00, 0x00, 0x00, 0x12, 0x01, 0x07, 0x21, 0x90,
 0x01, 0x05, 0x02, 0x01, 0x23, 0x20, 0x01, 0x07, 0x21, 0x90, 0x01, 0x05,
 0x44, 0x00
};

const VpProfileDataType RING_CAD_NOCID[] =
{
  /* Cadence Profile */
 0x00, 0x08, 0x00, 0x0E, 0x00, 0x00, 0x00, 0x0A, 0x01, 0x07, 0x21, 0x90,
 0x01, 0x05, 0x23, 0x20, 0x40, 0x00
};

const VpProfileDataType RING_CAD_US_CID[] =
{
  /* Cadence Profile */
 0x00, 0x08, 0x00, 0x16, 0x00, 0x00, 0x00, 0x12, 0x01, 0x07, 0x21, 0x90,
 0x01, 0x05, 0x02, 0x01, 0x23, 0x20, 0x01, 0x07, 0x21, 0x90, 0x01, 0x05,
 0x44, 0x00
};

/* Ringback Cadence */
const VpProfileDataType TONE_CAD_RNGBACK[] =
{
  /* Cadence Profile */
 0x00, 0x03, 0x01, 0x0E, 0x00, 0x00, 0x00, 0x0A, 0x00, 0x8F, 0x21, 0x90,
 0x00, 0x80, 0x23, 0x20, 0x40, 0x00
};

/* Ringing Always On */
const VpProfileDataType RING_CAD_ON[] =
{
  /* Cadence Profile */
 0x00, 0x03, 0x00, 0x08, 0x00, 0x00, 0x00, 0x04, 0x00, 0x8F, 0x20, 0x00

};

/* Receiver Off-Hook */
const VpProfileDataType TONE_CAD_ROH[] =
{
  /* Cadence Profile */
 0x00, 0x03, 0x01, 0x0E, 0x00, 0x00, 0x00, 0x0A, 0x00, 0x8F, 0x20, 0x14,
 0x00, 0x80, 0x20, 0x14, 0x40, 0x00
};

/* SIT Cadence */
const VpProfileDataType TONE_CAD_SIT[] =
{
  /* Cadence Profile */
 0x00, 0x03, 0x01, 0x14, 0x00, 0x00, 0x00, 0x10, 0x00, 0x81, 0x20, 0x3C,
 0x00, 0x82, 0x20, 0x3C, 0x00, 0x84, 0x20, 0x3C, 0x00, 0x80, 0x20, 0x00
};

const VpProfileDataType RING_CAD_UK_CID[] =
{
  /* Cadence Profile */
 0x00, 0x08, 0x01, 0x14, 0x00, 0x00, 0x00, 0x10, 0x02, 0x01, 0x07, 0x00,
 0x20, 0xC8, 0x01, 0x07, 0x21, 0x90, 0x01, 0x05, 0x23, 0x20, 0x43, 0x00
};

/************** Caller ID **************/

/* UK Caller ID Type I */
const VpProfileDataType CLI_TYPE1_UK[] =
{
  /* Space=2100Hz, Mark=1300Hz, Amp=-7.00dBm */
  /* Caller ID Profile */
  0x00, 0x05, 0x00, 0x42, 0x00, 0x00,
  0x09, 0xD4, /* MPI Length and Command */
  0x16, 0x66, 0x27, 0xD4, 0x0D, 0xDD, 0x27, 0xD4, /* MPI Data */
  0x00, 0x00, /* Checksum Part of Message Data */
  0x00, 0x32, /* Length of Elements Data */
  0x00, 0x06, 0x00, 0x32, /* Silence Interval for 50ms */
  0x00, 0x01, /* Line Reversal */
  0x00, 0x06, 0x00, 0x64, /* Silence Interval for 100ms */
  0x00, 0x04, /* Alert Tone */
  /* Caller ID Alert Tone for UK Cadence */
  /* 2130 Hz, -13.00 dBm0, 2750 Hz, -13.00 dBm0 */
  0x09, 0xD4, 0x16, 0xB8, 0x13, 0xF6, 0x1D, 0x55, 0x13, 0xF6,
  0x00, 0x05, 0x00, 0x64, /* Alert Tone Part 2 - Tone+Cadence = 100ms */
  0x00, 0x07, 0x00, 0x64, 0x00, 0x14, /* Silence Interval for 100ms, Masked-hook Interval for 20ms */
  0x00, 0x09, 0x00, 0x64, /* Channel Seizure for 100ms */
  0x00, 0x0A, 0x00, 0x32, /* Mark Signal for 50ms */
  0x00, 0x0B, /* Message Data */
  0x00, 0x06, 0x00, 0xC8, /* Silence Interval for 200ms */
  0x00, 0x01, /* Line Reversal */
  0x00, 0x0D  /* End of Transmission */
};

/* US Caller ID (Type 1 - On-Hook) */
const VpProfileDataType CLI_TYPE1_US[] =
{
  /* Space=2200Hz, Mark=1200Hz, Amp=-7.00dBm */
  /* Caller ID Profile */
  0x00, 0x05, 0x01, 0x20, 0x00, 0x00,
  0x09, 0xD4, /* MPI Length and Command */
  0x17, 0x77, 0x27, 0xD4, 0x0C, 0xCC, 0x27, 0xD4, /* MPI Data */
  0x00, 0x00, /* Checksum Part of Message Data */
  0x00, 0x10, /* Length of Elements Data */
  0x00, 0x06, 0x01, 0xF4, /* Silence Interval for 500ms */
  0x00, 0x09, 0x00, 0xFA, /* Channel Seizure for 250ms */
  0x00, 0x0A, 0x00, 0x96, /* Mark Signal for 150ms */
  0x00, 0x0B, /* Message Data */
  0x00, 0x0D  /* End of Transmission */
};

/* US and UK Type 2 Caller ID */
const VpProfileDataType CLI_TYPE2_US[] =
{
  /* Space=1200Hz, Mark=2100Hz, Amp=0.50dBm */
  /* Caller ID Profile */
  0x00, 0x06, 0x01, 0x12, 0x00, 0x09, 0xD4, 0x26, 0x66, 0x21, 0xE5, 0x43,
  0x33, 0x00,
  0x00, 0x00, /* Include Checksum */
  0x00, 0x02, /* Length of Elements Data */
  0x02, /* Mute the far end */
  0x0D, 0x00, 0x00  /* End of Transmission */
};

/************** Metering Profile **************/

/* Metering */
const VpProfileDataType METER_PROFILE[] =
{
  /* Metering Profile */
  0x00, 0x07, 0x01, 0x0A, 0x00, 0x05,
  0x6A, 0x00,   /* Smooth, 12 kHz Tone */
  0xD0, 0x01,  /* MLIM = 15.04 mVrms */
  0x2B, 0x00,  /* MTRA = 20.21 mA */
  0x00, 0x3C   /* On Period: 60 ms */
};

/************** FXO/Dialing Profile **************/

/* FXO/Dialing Profile */
const VpProfileDataType FXO_DIALING[] =
{
 /* FXO/Dialing Profile */
 0x00, 0xFE, 0x00, 0x12, 0x00, 0x00, 0x00, 0x28, 0x00, 0x28, 0x00, 0x78,
 0x0C, 0x08, 0x00, 0x28, 0xEB, 0x79, 0xCD, 0xCE, 0x23, 0x00
};

/* end of file profiles8.c */

#endif /* VP_CC_VCP_790_SERIES */

